﻿Imports System.ComponentModel
Imports System.Drawing
Imports System.Windows.Forms
Imports XCM

''' ---------------------------------------------
''' <summary>
''' BT_MultiRowDetailクラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
<Serializable()>
Public Class BT_MultiRowDetail

#Region "変数"
    Public Enum SelectMode As Integer
        None = 0
        Foreword = 1
        Back = 2
    End Enum

    Private pMinIndex As String
    Private pMaxIndex As String
#End Region

#Region "コンスタント"
    Private Const C_MIN_INDEX As String = "0000"
    Private Const C_MAX_INDEX As String = "9999"
    Private Const C_FORMAT As String = "0000"
#End Region

#Region "プロパティ"

    Private _Index As Integer = 0

    ''' ---------------------------------------------
    ''' <summary>
    ''' データソースのインデックス
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks>
    ''' 2010/07/21 新規作成　CS)平井<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    <Browsable(True)>
    <DefaultValue(0)>
    <Category("カスタムプロパティ")>
    <Description("データソースのインデックスを設定、取得します。")>
    Public Property Index As Integer
        Get
            Return _Index
        End Get
        Set(ByVal value As Integer)
            _Index = value
        End Set
    End Property

    Private _ViewIndex As Integer = 0

    ''' ---------------------------------------------
    ''' <summary>
    ''' 削除行を含まないインデックス
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks>
    ''' 2010/10/07 新規作成　CS)平井<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    <Browsable(True)>
    <DefaultValue(0)>
    <Category("カスタムプロパティ")>
    <Description("削除行を含まないのインデックスを設定、取得します。")>
    Public Property ViewIndex As Integer
        Get
            Return _ViewIndex
        End Get
        Set(ByVal value As Integer)
            _ViewIndex = value
        End Set
    End Property

    Private _DetailIndex As Integer = 0

    ''' ---------------------------------------------
    ''' <summary>
    ''' 明細部のインデックス
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks>
    ''' 2010/07/21 新規作成　CS)平井<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    <Browsable(True)>
    <DefaultValue(0)>
    <Category("カスタムプロパティ")> _
    <Description("明細部のインデックスを設定、取得します。")>
    Public Property DetailIndex As Integer
        Get
            Return _DetailIndex
        End Get
        Set(ByVal value As Integer)
            _DetailIndex = value
        End Set
    End Property

    Private _Updated As Boolean = False

    ''' ---------------------------------------------
    ''' <summary>
    ''' 明細部の更新フラグ
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks>
    ''' 2010/10/05 新規作成　CS)平井<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    <Browsable(True)>
    <DefaultValue(False)>
    <Category("カスタムプロパティ")> _
    <Description("明細部の更新フラグを設定、取得します。")>
    Public Property Updated As Boolean
        Get
            Return _Updated
        End Get
        Set(ByVal value As Boolean)
            _Updated = value
        End Set
    End Property

    ''' ---------------------------------------------
    ''' <summary>
    ''' コントロール名よりコントロールを取得する。
    ''' </summary>
    ''' <param name="strControlName"></param>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks>
    ''' 2010/10/14 新規作成　CS)平井<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    <Browsable(False)>
    <Category("カスタムプロパティ")> _
    <Description("コントロール名よりコントロールを取得します。")>
    Public ReadOnly Property Control(ByVal strControlName As String) As Control
        Get
            Dim ctl() As Control = Me.Controls.Find(strControlName, True)
            If ctl.Length > 0 Then
                Return ctl(0)
            Else
                Return Nothing
            End If
        End Get
    End Property

	Private _OrgSize As Size = New Size(0, 0)

	''' ---------------------------------------------
	''' <summary>
	''' 明細部の最初のサイズ
	''' </summary>
	''' <value></value>
	''' <returns></returns>
	''' <remarks>
	''' 2011/01/04 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	<Browsable(False)>
	<Category("カスタムプロパティ")> _
	<Description("明細部の最初のサイズを設定、取得します。")>
	Public Property OrgSize As Size
		Get
			Return _OrgSize
		End Get
		Set(ByVal value As Size)
			If _OrgSize.IsEmpty Then
				_OrgSize = value
			End If
		End Set
	End Property

#End Region

#Region "メソッド"

    ''' ---------------------------------------------
    ''' <summary>
    ''' 背景色を設定
    ''' </summary>
    ''' <param name="cl"></param>
    ''' <remarks>
    ''' 2010/07/21 新規作成　CS)平井<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    Public Sub SetBackColor(ByVal cl As Color, ByVal SpecialControlName As String)
		Try
			If String.IsNullOrEmpty(SpecialControlName) Then
				Call SetBackColorSub(Me, cl)
			Else
				Dim ctl() As Control = Me.Controls.Find(SpecialControlName, True)
				If ctl.Length > 0 Then
					Call SetBackColorSub(ctl(0), cl)
				End If
			End If
		Catch ex As Exception
			Throw
		End Try
    End Sub

    ''' ---------------------------------------------
    ''' <summary>
    ''' 背景色を設定（再帰）
    ''' </summary>
    ''' <param name="cl"></param>
    ''' <remarks>
    ''' 2010/07/21 新規作成　CS)平井<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    Private Sub SetBackColorSub(ByVal pctl As Control, ByVal cl As Color)
		Try
			pctl.BackColor = cl
			For Each ctl As Control In pctl.Controls
				If ctl.Controls.Count > 0 Then
					Call SetBackColorSub(ctl, cl)
				Else
					If TypeOf ctl Is Label Then
						ctl.BackColor = cl
					End If
				End If
			Next
		Catch ex As Exception
			Throw
		End Try
    End Sub

    ''' ---------------------------------------------
    ''' <summary>
    ''' 子コントロールの先頭または最後を選択
    ''' </summary>
    ''' <param name="SelMode"></param>
    ''' <remarks>
    ''' 2010/09/10 新規作成　CS)平井<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    Public Sub SelectRow(ByVal SelMode As SelectMode)
        Try
            Dim ctlSelect As Control = Nothing

            If SelMode = SelectMode.None Then
                ' 選択なし
                Me.Select()
                Exit Sub
            End If

            If SelMode = SelectMode.Foreword Then
                ' 前方
                pMinIndex = C_MAX_INDEX
                ctlSelect = GetMinControl(Me)
            Else
                ' 後方
                pMaxIndex = C_MIN_INDEX
                ctlSelect = GetMaxControl(Me)
            End If
            If ctlSelect IsNot Nothing Then
                ' 子コントロール選択
                ctlSelect.Select()
            Else
                Me.Select()
            End If
        Catch ex As Exception
            Throw
        End Try
    End Sub

    ''' ---------------------------------------------
    ''' <summary>
    ''' タブインデックスが最小のコントロールを取得
    ''' </summary>
    ''' <param name="ctlParent">親コントロール</param>
    ''' <returns>タブインデックス最小コントロール</returns>
    ''' <remarks>
    ''' 2010/09/10 新規作成　CS)平井<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    Private Function GetMinControl(ByVal ctlParent As Control) As Control
        Try
            Dim ctlRet As Control = Nothing
            For Each ctl As Control In ctlParent.Controls
				If ctl.Controls.Count > 0 AndAlso _
				   Not TypeOf ctl Is BT_Date AndAlso _
				   Not TypeOf ctl Is BT_Button Then
					Dim c As Control = GetMinControl(ctl)
					If c IsNot Nothing Then
						ctlRet = c
					End If
				End If
				If ctl.CanSelect AndAlso ctl.TabStop Then
					Dim strTabIndex As String = GetTabIndexString(ctl)
					If strTabIndex < pMinIndex Then
						pMinIndex = strTabIndex
						ctlRet = ctl
					End If
				End If
            Next
            Return ctlRet
        Catch ex As Exception
            Throw
        End Try
    End Function

    ''' ---------------------------------------------
    ''' <summary>
    ''' タブインデックスが最大のコントロールを取得
    ''' </summary>
    ''' <param name="ctlParent">親コントロール</param>
    ''' <returns>タブインデックス最大コントロール</returns>
    ''' <remarks>
    ''' 2010/09/10 新規作成　CS)平井<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    Private Function GetMaxControl(ByVal ctlParent As Control) As Control
        Try
            Dim ctlRet As Control = Nothing
            For Each ctl As Control In ctlParent.Controls
				If ctl.Controls.Count > 0 AndAlso _
				   Not TypeOf ctl Is BT_Date AndAlso _
				   Not TypeOf ctl Is BT_Button Then
					Dim c As Control = GetMaxControl(ctl)
					If c IsNot Nothing Then
						ctlRet = c
					End If
				End If
				If ctl.CanSelect AndAlso ctl.TabStop Then
					Dim strTabIndex As String = GetTabIndexString(ctl)
					If strTabIndex > pMaxIndex Then
						pMaxIndex = strTabIndex
						ctlRet = ctl
					End If
				End If
            Next
            Return ctlRet
        Catch ex As Exception
            Throw
        End Try
    End Function

    ''' ---------------------------------------------
    ''' <summary>
    ''' タブインデックスを文字列で取得する。
    ''' </summary>
    ''' <param name="ctl"></param>
    ''' <returns></returns>
    ''' <remarks>
    ''' 2010/10/06 新規作成　CS)平井<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    Private Function GetTabIndexString(ByVal ctl As Control) As String
        Try
            Dim strTabIndex As String = ""
            Dim c As Control = ctl
            Do
                If TypeOf c Is BT_MultiRowDetail Then
                    Exit Do
                End If
                strTabIndex = Format(c.TabIndex, C_FORMAT) & strTabIndex
                If c.Parent Is Nothing Then
                    Exit Do
                End If
                c = c.Parent
            Loop
            Return strTabIndex
        Catch ex As Exception
            Throw
        End Try
    End Function

#End Region

End Class
