﻿Imports System.Configuration
Imports System.Reflection
Imports XCM

''' ---------------------------------------------
''' <summary>
''' 医事システム連携　継承元
''' </summary>
''' <remarks>
''' Copyright 2012 FUJITSU SYSTEMS WEST LIMITED All rights reserved.<BR/>
''' FUJITSU SYSTEMS WEST LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public MustInherit Class XIJ000C010
	Implements IDisposable

#Region "コンスタント"

	Private Const CST_NO_CONFIG As String = "Configファイルがありません。（{0}）"
	Private Const CST_NO_ODBC_DRIVER As String = "ODBCドライバー名がありません。（{0}）"
	Private Const CST_NO_DATASOURCE As String = "データソース名がありません。（{0}）"
	Private Const CST_ODBC_DRIVER As String = "ODBCDriver"		'ODBCドライバー名
	Private Const CST_DATASOURCE_ORACLE As String = "DNQ"		'データソース名（ORACLE製ドライバー用）
	Private Const CST_DATASOURCE_MICROSOFT As String = "Server"	'データソース名（Microsoft製ドライバー用）
	Private Const CST_USERID As String = "UID"					'ユーザーＩＤ
	Private Const CST_PASSWORD As String = "PWD"				'パスワード

#End Region

#Region "変数"

	Protected Friend ODBCConfig As datODBCConfig

#End Region

#Region "解放処理"

	' 解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------
	''' <summary>
	''' 開放処理
	''' </summary>
	''' <remarks>
	''' 2012/11/16 新規作成　FWEST)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		MyBase.Finalize()
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 開放処理（実処理）
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2012/11/16 新規作成　FWEST)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overridable Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
			Try
				If disposing Then
					' マネージリソースの解放
					ODBCConfig = Nothing
				End If
			Finally
				' アンマネージリソースの解放、終了時に必ず行う処理
			End Try
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' デストラクタ
	''' </summary>
	''' <remarks>
	''' 2012/11/16 新規作成　FWEST)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub

#End Region

#Region "コンストラクタ"

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <remarks>
	''' 2012/11/16 新規作成　FWEST)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub New()
		ODBCConfig = getXMLurl()
	End Sub

#End Region

#Region "メソッド"

	''' ----------------------------------------------
	''' <summary>
	''' 初期値ファイルのURL読み込み
	''' </summary>
	''' <returns></returns>
	''' <remarks>
	''' 2012/11/16 新規作成　FWEST)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getXMLurl() As datODBCConfig
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "医事システム連携", "継承元", "初期値ファイルのURL読み込み Start")
		Dim ret As datODBCConfig = Nothing								'戻り値
		Dim strODBCDriver As String = Nothing							'ODBCドライバー名
		Dim strDNQ As String = Nothing									'データソース名（ORACLE製ドライバー用）
		Dim strServer As String = Nothing								'データソース名（Microsoft製ドライバー用）
		Dim strUID As String = Nothing									'ユーザーＩＤ
		Dim strPWD As String = Nothing									'パスワード
		Dim asmloc As String = Nothing									'アセンブリファイル位置
		Dim cfgDll As Configuration = Nothing							'DLL用Configファイル内容
		Dim appSettings As AppSettingsSection = Nothing					'appSettingsセクションの内容
		Try
			asmloc = Me.GetType.Assembly.Location						'アセンブリファイル位置を取得
			cfgDll = ConfigurationManager.OpenExeConfiguration(asmloc)	'DLL用Configファイル内容を取得
			appSettings = cfgDll.AppSettings							'appSettingsセクションの内容を取得
			If appSettings.Settings.Count = 0 Then						'appSettingsセクションの内容がなければ
				Dim errmsg As String = String.Format(CST_NO_CONFIG, cfgDll.FilePath)
				Throw New Exception(errmsg)								'エラー「Configファイルがありません」
			End If
			For Each el As KeyValueConfigurationElement In appSettings.Settings
				Select Case el.Key.ToLower
					Case CST_ODBC_DRIVER.ToLower						'ODBCドライバー名
						strODBCDriver = el.Value
					Case CST_DATASOURCE_ORACLE.ToLower					'データソース名（ORACLE製ドライバー用）
						strDNQ = el.Value
					Case CST_DATASOURCE_MICROSOFT.ToLower				'データソース名（Microsoft製ドライバー用）
						strServer = el.Value
					Case CST_USERID.ToLower								'ユーザーＩＤ
						strUID = el.Value
					Case CST_PASSWORD.ToLower							'パスワード
						strPWD = appSettings.Settings("PWD").Value
					Case Else
				End Select
			Next
			ret = New datODBCConfig										'戻り値をインスタンス化
			If String.IsNullOrWhiteSpace(strODBCDriver) Then			'ODBCドライバー名に内容がなければ
				Dim errmsg As String = String.Format(CST_NO_ODBC_DRIVER, cfgDll.FilePath)
				Throw New Exception(errmsg)								'エラー「ODBCドライバー名がありません」
			End If
			Select Case False
				Case String.IsNullOrWhiteSpace(strDNQ)					'データソース名（ORACLE製ドライバー用）に内容があれば
					ret.Vendor = datODBCConfig.Enum_Vendor.ORACLE		'ODBCドライバー提供ベンダーはORACLE
				Case String.IsNullOrWhiteSpace(strServer)				'データソース名（Microsoft製ドライバー用）に内容があれば
					ret.Vendor = datODBCConfig.Enum_Vendor.Microsoft	'ODBCドライバー提供ベンダーはMicrosoft
				Case Else												'データソース名に内容がなければ
					Dim errmsg As String = String.Format(CST_NO_DATASOURCE, cfgDll.FilePath)
					Throw New Exception(errmsg)							'エラー「データソース名がありません」
			End Select
			ret.ODBCDriver = strODBCDriver								'ODBCドライバー名
			ret.DNQ = strDNQ											'データソース名（ORACLE製ドライバー用）
			ret.Server = strServer										'データソース名（Microsoft製ドライバー用）
			ret.UID = strUID											'ユーザーＩＤ
			ret.PWD = strPWD											'パスワード
		Catch ex As Exception
			Throw
		Finally
			cfgDll = Nothing
			appSettings = Nothing
		End Try
		Return ret
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 部分文字列取得
	''' </summary>
	''' <param name="target">対象文字列</param>
	''' <param name="startIndex">0から始まる開始文字位置</param>
	''' <param name="length">部分文字列の文字数</param>
	''' <returns>部分文字列</returns>
	''' <remarks>
	''' 2012/11/16 新規作成　FWEST)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getSubstringEx(ByVal target As String, ByVal startIndex As Integer, length As Integer) As String
		Try
			Select Case True
				Case target.Length < startIndex
					Return String.Empty
				Case target.Length < startIndex + length
					Return target.Substring(startIndex)
				Case Else
					Return target.Substring(startIndex, length)
			End Select
		Catch ex As Exception
			Throw
		End Try
	End Function
#End Region

End Class
