﻿Imports XCM
Imports XSP
Imports System.Runtime.ConstrainedExecution

''' ---------------------------------------------
''' <summary>
''' 医療機関マスタ　Report出力クラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public Class XMS130R010

#Region "解放処理"
    '確実な解放処理を実行するために指定
    Inherits CriticalFinalizerObject
    '解放処理を実装する為に指定
    Implements IDisposable

    ''' ---------------------------------------------
    ''' <summary>
    ''' Dispose（解放処理）※外からはよばない
    ''' </summary>
    ''' <param name="disposing"></param>
    ''' <remarks>
	''' 2010/12/06 新規作成 CS)徳増<BR/>
	''' </remarks>
    ''' ---------------------------------------------
    Protected Overloads Sub Dispose(ByVal disposing As Boolean)
        If disposing Then
			pFrm = Nothing					'フォーム
            pValuePrint = Nothing           '印刷フラグ
		End If
    End Sub

    ''' ---------------------------------------------
    ''' <summary>
    ''' Finalize（解放処理）
    ''' </summary>
    ''' <remarks>
	''' 2010/12/06 新規作成 CS)徳増<BR/>
	''' </remarks>
    ''' ---------------------------------------------
    Public Overloads Sub Dispose() Implements IDisposable.Dispose
        Dispose(True)
        MyBase.Finalize()
        GC.SuppressFinalize(Me)
    End Sub

    ''' ---------------------------------------------
    ''' <summary>
    ''' Finalize（解放処理）※外からはよばない
    ''' </summary>
    ''' <remarks>
	''' 2010/12/06 新規作成 CS)徳増<BR/>
	''' </remarks>
    ''' ---------------------------------------------
    Protected Overrides Sub Finalize()
        Dispose(False)
        MyBase.Finalize()
    End Sub
#End Region

#Region "変数"

	'IN項目
    Private pFrm As frmBase = Nothing                                   'フォーム
    Private pValuePrint As Boolean = Nothing                            '印刷フラグ

#End Region

#Region "コンスタント"

    '帳票タイトル(頭書コメントトップが空白時使用)
    Private Const LEDGERSHEET_TITLE As String = "医療機関マスタ"

#End Region

#Region "コンストラクタ"

    ''' ---------------------------------------------
    ''' <summary>
    ''' コンストラクタ
    ''' </summary>
    ''' <param name="pForm">frmBase</param>
    ''' <remarks>
	''' 2010/12/06 新規作成 CS)徳増<BR/>
	''' </remarks>
    ''' ---------------------------------------------
	Sub New(ByVal pForm As Form)
		'IN項目引き継ぎ
		pFrm = pForm					'画面ID
	End Sub

#End Region

#Region "メソッド"

	''' ---------------------------------------------
	''' <summary>
	''' 印刷・プレビュー処理（医療機関マスタ）
	''' </summary>
	''' <param name="pValuePrint">TRUE:印刷 FALSE:プレビュー</param>			
	''' <remarks>
	''' 2010/12/06 新規作成 CS)徳増<BR/>
	''' </remarks>
	''' ---------------------------------------------
    Public Function Prn_MED_AGENCY(ByVal pValuePrint As Boolean) As Boolean
        pFrm.log(clsSysMst.logLevel.DBG, "Prn_MED_AGENCY", "印刷・プレビュー処理（医療機関マスタ） START")

        Dim FilePath As String = Nothing                                'MDBファイルパス（フルパス）
        Dim cliAccess As New clsXTM_PRINTSETTING_ACCESS                 'ACCESS設定情報アクセスクラス
        Dim datAccess As datXTM_PRINTSETTING_ACCESS_OneRec = Nothing    'ACCESS設定情報データクラス
		Dim datHeader As datHeader = Nothing							'ヘッダーデータクラス
		Dim cliCom As New clsCom										'共通クラス
		Dim intCnt As Integer = 0
		Try
			'ヘッダー情報作成
			datHeader = Me.getHeaderData

			'印刷設定情報取得
			datAccess = cliAccess.getAccessSettingOneRec(Me.pFrm.Name, Me.GetType.Name)
			If datAccess Is Nothing Then
				Return False
			End If

			'MDBファイルパス設定
			FilePath = cliCom.setReportPath(datAccess.FILE_NM)

			Using cliReportFunc As New clsReportFunc(Me.pFrm, FilePath, datAccess.REPORT_NM, pValuePrint)
				'ワークMDB更新処理
				Using db As New clsDB(clsSysMst.ctlConfigData)

					'医療機関マスタのデータ件数をチェック
					intCnt = Me.getDetailDataCount(db)

					'データ件数が０件の場合はメッセージを表示し、終了
					If intCnt = 0 Then
						pFrm.showMsg("I0001")	 '該当するデータはありませんでした。
						Return False
					End If

					'ヘッダーワーク削除
					Call cliReportFunc.exeHeaderDel(db, datAccess.REPORT_NM, True)

					'ワークテーブルの追加
					Call cliReportFunc.exeHeaderIns(db, datHeader, True)

					'AcPrint内でレポートの存在チェックを行う()
					'そのため、独自ロジックは組まない。
					If Not cliReportFunc.AcPrint(datAccess.NUMBERPRINTED) Then
						Return False
					End If
				End Using
			End Using
			Return True
		Catch ex As Exception
			Throw
		Finally
			FilePath = Nothing
			cliAccess = Nothing
			datAccess = Nothing
			datHeader = Nothing
			cliCom = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ヘッダーデータ取得
	''' </summary>
	''' <returns>ヘッダーデータ</returns>
	''' <remarks>
	''' 2010/12/06 新規作成 CS)徳増<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getHeaderData() As datHeader
		clsSysMst.logEx(clsSysMst.logLevel.DBG, "XMS", Me.GetType.Name, "getHeaderData", "医療機関マスタ印刷", "医療機関マスタ（Report）", "ヘッダーデータ取得 START")
		Dim retHeader As New datHeader
		Try
			With retHeader
				'帳票ID
				.PRT_ID = Me.GetType.Name
				'タイトル	
				.TITLE_NM = LEDGERSHEET_TITLE
			End With
			Return retHeader
		Catch ex As Exception
			Throw
		Finally
			retHeader = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 明細データ件数取得（医療機関マスタ）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <returns>件数</returns>
	''' <remarks>
	''' 2010/12/06 新規作成 CS)徳増<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getDetailDataCount(ByVal db As clsDB) As Integer
		clsSysMst.logEx(clsSysMst.logLevel.DBG, "XMS", Me.GetType.Name, "getDetailDataCount", "医療機関マスタ印刷", "医療機関マスタ（Report）", "明細データ件数取得 START")
		Dim arData As ArrayList = New ArrayList()
		Dim dbData As datXMS130R010_Cnt = Nothing
		Dim iRet As Long = 0
		Try
			db.setSQL(sqlXMS130R010.sqlSel_MTM_MED_AGENCY_Cnt)	'SELECT文設定
			iRet = db.execQuery(GetType(datXMS130R010_Cnt), arData)	'値取得
			If iRet > 0 Then										'レコードあり
				dbData = DirectCast(arData(0), datXMS130R010_Cnt)
				Return dbData.CNT
			Else
				Return 0
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
			dbData = Nothing
		End Try
	End Function

#End Region

End Class