﻿Imports XCM
Imports System.Reflection

''' ---------------------------------------------
''' <summary>
''' 補足項目１情報アクセスクラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class clsMTI_ASST1
	Implements IDisposable

#Region "解放処理"

	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------	
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New()
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String) As Boolean
		Try
			Return Not String.IsNullOrWhiteSpace(pPatientNo)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo) AndAlso (pHspHistoryNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo) AndAlso (pChNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の補足項目１情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の補足項目１情報（ArrayList内にdatMTI_ASST1_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getAsst1Hsp(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getAsst1Hsp(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の補足項目１情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の補足項目１情報（ArrayList内にdatMTI_ASST1_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getAsst1Hsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_ASST1.sqlSelAsst1_Hsp)	'SELECT文設定
			db.setParam(sqlMTI_ASST1.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_ASST1.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setVal(sqlMTI_ASST1.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_ASST1.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			iRet = db.execQuery(GetType(datMTI_ASST1_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の補足項目１情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１入退院分の補足項目１情報</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getAsst1HspDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getAsst1HspDa(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の補足項目１情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の補足項目１情報</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getAsst1HspDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_ASST1.sqlSelAsst1_Hsp)	'SELECT文設定

			db.setParamDa(sqlMTI_ASST1.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_ASST1.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setValDa(sqlMTI_ASST1.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_ASST1.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 補足項目１情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>補足項目１情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getAsst1OneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As datMTI_ASST1_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getAsst1OneRec(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 補足項目１情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>補足項目１情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getAsst1OneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As datMTI_ASST1_OneRec
		Dim retDat As datMTI_ASST1_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_ASST1.sqlSelAsst1_OneRec)	'SELECT文設定
			db.setParam(sqlMTI_ASST1.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_ASST1.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_ASST1.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setVal(sqlMTI_ASST1.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_ASST1.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_ASST1.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_ASST1_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_ASST1_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 補足項目１情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>補足項目１情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getAsst1OneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getAsst1OneRecDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 補足項目１情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>補足項目１情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getAsst1OneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_ASST1.sqlSelAsst1_OneRec)

			db.setParamDa(sqlMTI_ASST1.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_ASST1.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParamDa(sqlMTI_ASST1.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
			db.setValDa(sqlMTI_ASST1.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_ASST1.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_ASST1.prmCH_NO, pChNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の補足項目１情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelAsst1Patient(ByVal db As clsDB, ByVal pPatientNo As String)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "補足項目１情報アクセスクラス", "１患者分の補足項目１情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo) Then
				' 削除実行
				db.setSQL(sqlMTI_ASST1.sqlDelAsst1_Patient)	'DELETE文設定
				db.setParam(sqlMTI_ASST1.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
				db.setVal(sqlMTI_ASST1.prmPATIENT_NO, pPatientNo)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の補足項目１情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelAsst1Hsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "補足項目１情報アクセスクラス", "１入退院分の補足項目１情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo) Then
				' 削除実行
				db.setSQL(sqlMTI_ASST1.sqlDelAsst1_Hsp)	'DELETE文設定
				db.setParam(sqlMTI_ASST1.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
				db.setParam(sqlMTI_ASST1.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
				db.setVal(sqlMTI_ASST1.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_ASST1.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 補足項目１情報１データを削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelAsst1OneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "補足項目１情報アクセスクラス", "補足項目１情報１データを削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				' 削除実行
				db.setSQL(sqlMTI_ASST1.sqlDelAsst1_OneRec)	'DELETE文設定
				db.setParam(sqlMTI_ASST1.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
				db.setParam(sqlMTI_ASST1.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
				db.setParam(sqlMTI_ASST1.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
				db.setVal(sqlMTI_ASST1.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_ASST1.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_ASST1.prmCH_NO, pChNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 補足項目１情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pAsst1Rec">補足項目１情報クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsAsst1OneRec(ByVal db As clsDB, ByVal pAsst1Rec As datMTI_ASST1_OneRec) As Integer
		Try
			Return execInsAsst1OneRec(db, pAsst1Rec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 補足項目１情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pAsst1Rec">補足項目１情報クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsAsst1OneRec(ByVal db As clsDB, ByVal pAsst1Rec As datMTI_ASST1_OneRec, ByVal bLastUpdate As Boolean) As Integer
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "補足項目１情報アクセスクラス", "補足項目１情報１データを追加 Start")
		Try
			If pAsst1Rec Is Nothing Then
				Return 0
			End If
			Select Case False
				Case (pAsst1Rec.ASST_ITM001 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM002 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM003 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM004 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM005 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM006 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM007 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM008 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM009 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM010 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM011 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM012 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM013 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM014 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM015 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM016 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM017 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM018 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM019 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM020 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM021 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM022 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM023 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM024 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM025 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM026 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM027 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM028 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM029 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM030 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM031 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM032 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM033 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM034 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM035 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM036 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM037 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM038 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM039 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM040 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM041 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM042 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM043 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM044 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM045 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM046 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM047 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM048 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM049 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM050 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM051 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM052 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM053 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM054 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM055 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM056 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM057 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM058 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM059 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM060 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM061 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM062 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM063 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM064 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM065 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM066 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM067 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM068 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM069 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM070 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM071 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM072 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM073 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM074 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM075 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM076 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM077 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM078 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM079 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM080 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM081 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM082 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM083 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM084 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM085 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM086 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM087 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM088 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM089 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM090 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM091 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM092 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM093 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM094 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM095 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM096 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM097 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM098 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM099 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM100 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM101 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM102 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM103 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM104 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM105 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM106 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM107 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM108 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM109 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM110 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM111 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM112 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM113 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM114 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM115 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM116 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM117 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM118 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM119 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM120 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM121 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM122 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM123 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM124 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM125 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM126 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM127 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM128 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM129 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM130 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM131 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case (pAsst1Rec.ASST_ITM132 = clsConst.Enum_CheckBox_Flg.CheckOff)
				Case Else
					' 全てオフなら追加しない
					Return 0
			End Select
			' INSERT文設定
			db.setSQL(sqlMTI_ASST1.sqlInsAsst1_OneRec)
			' 患者番号
			db.setParam(sqlMTI_ASST1.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST1.prmPATIENT_NO, pAsst1Rec.PATIENT_NO)
			' 入退院歴番号
			db.setParam(sqlMTI_ASST1.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmHSP_HISTORY_NO, pAsst1Rec.HSP_HISTORY_NO, False)
			' 科歴番号
			db.setParam(sqlMTI_ASST1.prmCH_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmCH_NO, pAsst1Rec.CH_NO, False)
			' 補足項目０１
			db.setParam(sqlMTI_ASST1.prmASST_ITM001, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM001, pAsst1Rec.ASST_ITM001, False)
			' 補足項目０２
			db.setParam(sqlMTI_ASST1.prmASST_ITM002, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM002, pAsst1Rec.ASST_ITM002, False)
			' 補足項目０３
			db.setParam(sqlMTI_ASST1.prmASST_ITM003, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM003, pAsst1Rec.ASST_ITM003, False)
			' 補足項目０４
			db.setParam(sqlMTI_ASST1.prmASST_ITM004, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM004, pAsst1Rec.ASST_ITM004, False)
			' 補足項目０５
			db.setParam(sqlMTI_ASST1.prmASST_ITM005, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM005, pAsst1Rec.ASST_ITM005, False)
			' 補足項目０６
			db.setParam(sqlMTI_ASST1.prmASST_ITM006, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM006, pAsst1Rec.ASST_ITM006, False)
			' 補足項目０７
			db.setParam(sqlMTI_ASST1.prmASST_ITM007, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM007, pAsst1Rec.ASST_ITM007, False)
			' 補足項目０８
			db.setParam(sqlMTI_ASST1.prmASST_ITM008, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM008, pAsst1Rec.ASST_ITM008, False)
			' 補足項目０９
			db.setParam(sqlMTI_ASST1.prmASST_ITM009, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM009, pAsst1Rec.ASST_ITM009, False)
			' 補足項目１０
			db.setParam(sqlMTI_ASST1.prmASST_ITM010, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM010, pAsst1Rec.ASST_ITM010, False)
			' 補足項目１１
			db.setParam(sqlMTI_ASST1.prmASST_ITM011, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM011, pAsst1Rec.ASST_ITM011, False)
			' 補足項目１２
			db.setParam(sqlMTI_ASST1.prmASST_ITM012, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM012, pAsst1Rec.ASST_ITM012, False)
			' 補足項目１３
			db.setParam(sqlMTI_ASST1.prmASST_ITM013, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM013, pAsst1Rec.ASST_ITM013, False)
			' 補足項目１４
			db.setParam(sqlMTI_ASST1.prmASST_ITM014, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM014, pAsst1Rec.ASST_ITM014, False)
			' 補足項目１５
			db.setParam(sqlMTI_ASST1.prmASST_ITM015, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM015, pAsst1Rec.ASST_ITM015, False)
			' 補足項目１６
			db.setParam(sqlMTI_ASST1.prmASST_ITM016, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM016, pAsst1Rec.ASST_ITM016, False)
			' 補足項目１７
			db.setParam(sqlMTI_ASST1.prmASST_ITM017, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM017, pAsst1Rec.ASST_ITM017, False)
			' 補足項目１８
			db.setParam(sqlMTI_ASST1.prmASST_ITM018, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM018, pAsst1Rec.ASST_ITM018, False)
			' 補足項目１９
			db.setParam(sqlMTI_ASST1.prmASST_ITM019, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM019, pAsst1Rec.ASST_ITM019, False)
			' 補足項目２０
			db.setParam(sqlMTI_ASST1.prmASST_ITM020, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM020, pAsst1Rec.ASST_ITM020, False)
			' 補足項目２１
			db.setParam(sqlMTI_ASST1.prmASST_ITM021, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM021, pAsst1Rec.ASST_ITM021, False)
			' 補足項目２２
			db.setParam(sqlMTI_ASST1.prmASST_ITM022, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM022, pAsst1Rec.ASST_ITM022, False)
			' 補足項目２３
			db.setParam(sqlMTI_ASST1.prmASST_ITM023, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM023, pAsst1Rec.ASST_ITM023, False)
			' 補足項目２４
			db.setParam(sqlMTI_ASST1.prmASST_ITM024, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM024, pAsst1Rec.ASST_ITM024, False)
			' 補足項目２５
			db.setParam(sqlMTI_ASST1.prmASST_ITM025, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM025, pAsst1Rec.ASST_ITM025, False)
			' 補足項目２６
			db.setParam(sqlMTI_ASST1.prmASST_ITM026, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM026, pAsst1Rec.ASST_ITM026, False)
			' 補足項目２７
			db.setParam(sqlMTI_ASST1.prmASST_ITM027, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM027, pAsst1Rec.ASST_ITM027, False)
			' 補足項目２８
			db.setParam(sqlMTI_ASST1.prmASST_ITM028, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM028, pAsst1Rec.ASST_ITM028, False)
			' 補足項目２９
			db.setParam(sqlMTI_ASST1.prmASST_ITM029, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM029, pAsst1Rec.ASST_ITM029, False)
			' 補足項目３０
			db.setParam(sqlMTI_ASST1.prmASST_ITM030, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM030, pAsst1Rec.ASST_ITM030, False)
			' 補足項目３１
			db.setParam(sqlMTI_ASST1.prmASST_ITM031, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM031, pAsst1Rec.ASST_ITM031, False)
			' 補足項目３２
			db.setParam(sqlMTI_ASST1.prmASST_ITM032, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM032, pAsst1Rec.ASST_ITM032, False)
			' 補足項目３３
			db.setParam(sqlMTI_ASST1.prmASST_ITM033, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM033, pAsst1Rec.ASST_ITM033, False)
			' 補足項目３４
			db.setParam(sqlMTI_ASST1.prmASST_ITM034, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM034, pAsst1Rec.ASST_ITM034, False)
			' 補足項目３５
			db.setParam(sqlMTI_ASST1.prmASST_ITM035, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM035, pAsst1Rec.ASST_ITM035, False)
			' 補足項目３６
			db.setParam(sqlMTI_ASST1.prmASST_ITM036, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM036, pAsst1Rec.ASST_ITM036, False)
			' 補足項目３７
			db.setParam(sqlMTI_ASST1.prmASST_ITM037, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM037, pAsst1Rec.ASST_ITM037, False)
			' 補足項目３８
			db.setParam(sqlMTI_ASST1.prmASST_ITM038, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM038, pAsst1Rec.ASST_ITM038, False)
			' 補足項目３９
			db.setParam(sqlMTI_ASST1.prmASST_ITM039, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM039, pAsst1Rec.ASST_ITM039, False)
			' 補足項目４０
			db.setParam(sqlMTI_ASST1.prmASST_ITM040, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM040, pAsst1Rec.ASST_ITM040, False)
			' 補足項目４１
			db.setParam(sqlMTI_ASST1.prmASST_ITM041, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM041, pAsst1Rec.ASST_ITM041, False)
			' 補足項目４２
			db.setParam(sqlMTI_ASST1.prmASST_ITM042, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM042, pAsst1Rec.ASST_ITM042, False)
			' 補足項目４３
			db.setParam(sqlMTI_ASST1.prmASST_ITM043, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM043, pAsst1Rec.ASST_ITM043, False)
			' 補足項目４４
			db.setParam(sqlMTI_ASST1.prmASST_ITM044, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM044, pAsst1Rec.ASST_ITM044, False)
			' 補足項目４５
			db.setParam(sqlMTI_ASST1.prmASST_ITM045, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM045, pAsst1Rec.ASST_ITM045, False)
			' 補足項目４６
			db.setParam(sqlMTI_ASST1.prmASST_ITM046, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM046, pAsst1Rec.ASST_ITM046, False)
			' 補足項目４７
			db.setParam(sqlMTI_ASST1.prmASST_ITM047, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM047, pAsst1Rec.ASST_ITM047, False)
			' 補足項目４８
			db.setParam(sqlMTI_ASST1.prmASST_ITM048, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM048, pAsst1Rec.ASST_ITM048, False)
			' 補足項目４９
			db.setParam(sqlMTI_ASST1.prmASST_ITM049, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM049, pAsst1Rec.ASST_ITM049, False)
			' 補足項目５０
			db.setParam(sqlMTI_ASST1.prmASST_ITM050, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM050, pAsst1Rec.ASST_ITM050, False)
			' 補足項目５１
			db.setParam(sqlMTI_ASST1.prmASST_ITM051, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM051, pAsst1Rec.ASST_ITM051, False)
			' 補足項目５２
			db.setParam(sqlMTI_ASST1.prmASST_ITM052, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM052, pAsst1Rec.ASST_ITM052, False)
			' 補足項目５３
			db.setParam(sqlMTI_ASST1.prmASST_ITM053, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM053, pAsst1Rec.ASST_ITM053, False)
			' 補足項目５４
			db.setParam(sqlMTI_ASST1.prmASST_ITM054, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM054, pAsst1Rec.ASST_ITM054, False)
			' 補足項目５５
			db.setParam(sqlMTI_ASST1.prmASST_ITM055, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM055, pAsst1Rec.ASST_ITM055, False)
			' 補足項目５６
			db.setParam(sqlMTI_ASST1.prmASST_ITM056, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM056, pAsst1Rec.ASST_ITM056, False)
			' 補足項目５７
			db.setParam(sqlMTI_ASST1.prmASST_ITM057, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM057, pAsst1Rec.ASST_ITM057, False)
			' 補足項目５８
			db.setParam(sqlMTI_ASST1.prmASST_ITM058, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM058, pAsst1Rec.ASST_ITM058, False)
			' 補足項目５９
			db.setParam(sqlMTI_ASST1.prmASST_ITM059, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM059, pAsst1Rec.ASST_ITM059, False)
			' 補足項目６０
			db.setParam(sqlMTI_ASST1.prmASST_ITM060, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM060, pAsst1Rec.ASST_ITM060, False)
			' 補足項目６１
			db.setParam(sqlMTI_ASST1.prmASST_ITM061, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM061, pAsst1Rec.ASST_ITM061, False)
			' 補足項目６２
			db.setParam(sqlMTI_ASST1.prmASST_ITM062, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM062, pAsst1Rec.ASST_ITM062, False)
			' 補足項目６３
			db.setParam(sqlMTI_ASST1.prmASST_ITM063, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM063, pAsst1Rec.ASST_ITM063, False)
			' 補足項目６４
			db.setParam(sqlMTI_ASST1.prmASST_ITM064, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM064, pAsst1Rec.ASST_ITM064, False)
			' 補足項目６５
			db.setParam(sqlMTI_ASST1.prmASST_ITM065, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM065, pAsst1Rec.ASST_ITM065, False)
			' 補足項目６６
			db.setParam(sqlMTI_ASST1.prmASST_ITM066, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM066, pAsst1Rec.ASST_ITM066, False)
			' 補足項目６７
			db.setParam(sqlMTI_ASST1.prmASST_ITM067, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM067, pAsst1Rec.ASST_ITM067, False)
			' 補足項目６８
			db.setParam(sqlMTI_ASST1.prmASST_ITM068, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM068, pAsst1Rec.ASST_ITM068, False)
			' 補足項目６９
			db.setParam(sqlMTI_ASST1.prmASST_ITM069, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM069, pAsst1Rec.ASST_ITM069, False)
			' 補足項目７０
			db.setParam(sqlMTI_ASST1.prmASST_ITM070, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM070, pAsst1Rec.ASST_ITM070, False)
			' 補足項目７１
			db.setParam(sqlMTI_ASST1.prmASST_ITM071, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM071, pAsst1Rec.ASST_ITM071, False)
			' 補足項目７２
			db.setParam(sqlMTI_ASST1.prmASST_ITM072, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM072, pAsst1Rec.ASST_ITM072, False)
			' 補足項目７３
			db.setParam(sqlMTI_ASST1.prmASST_ITM073, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM073, pAsst1Rec.ASST_ITM073, False)
			' 補足項目７４
			db.setParam(sqlMTI_ASST1.prmASST_ITM074, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM074, pAsst1Rec.ASST_ITM074, False)
			' 補足項目７５
			db.setParam(sqlMTI_ASST1.prmASST_ITM075, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM075, pAsst1Rec.ASST_ITM075, False)
			' 補足項目７６
			db.setParam(sqlMTI_ASST1.prmASST_ITM076, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM076, pAsst1Rec.ASST_ITM076, False)
			' 補足項目７７
			db.setParam(sqlMTI_ASST1.prmASST_ITM077, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM077, pAsst1Rec.ASST_ITM077, False)
			' 補足項目７８
			db.setParam(sqlMTI_ASST1.prmASST_ITM078, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM078, pAsst1Rec.ASST_ITM078, False)
			' 補足項目７９
			db.setParam(sqlMTI_ASST1.prmASST_ITM079, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM079, pAsst1Rec.ASST_ITM079, False)
			' 補足項目８０
			db.setParam(sqlMTI_ASST1.prmASST_ITM080, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM080, pAsst1Rec.ASST_ITM080, False)
			' 補足項目８１
			db.setParam(sqlMTI_ASST1.prmASST_ITM081, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM081, pAsst1Rec.ASST_ITM081, False)
			' 補足項目８２
			db.setParam(sqlMTI_ASST1.prmASST_ITM082, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM082, pAsst1Rec.ASST_ITM082, False)
			' 補足項目８３
			db.setParam(sqlMTI_ASST1.prmASST_ITM083, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM083, pAsst1Rec.ASST_ITM083, False)
			' 補足項目８４
			db.setParam(sqlMTI_ASST1.prmASST_ITM084, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM084, pAsst1Rec.ASST_ITM084, False)
			' 補足項目８５
			db.setParam(sqlMTI_ASST1.prmASST_ITM085, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM085, pAsst1Rec.ASST_ITM085, False)
			' 補足項目８６
			db.setParam(sqlMTI_ASST1.prmASST_ITM086, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM086, pAsst1Rec.ASST_ITM086, False)
			' 補足項目８７
			db.setParam(sqlMTI_ASST1.prmASST_ITM087, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM087, pAsst1Rec.ASST_ITM087, False)
			' 補足項目８８
			db.setParam(sqlMTI_ASST1.prmASST_ITM088, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM088, pAsst1Rec.ASST_ITM088, False)
			' 補足項目８９
			db.setParam(sqlMTI_ASST1.prmASST_ITM089, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM089, pAsst1Rec.ASST_ITM089, False)
			' 補足項目９０
			db.setParam(sqlMTI_ASST1.prmASST_ITM090, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM090, pAsst1Rec.ASST_ITM090, False)
			' 補足項目９１
			db.setParam(sqlMTI_ASST1.prmASST_ITM091, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM091, pAsst1Rec.ASST_ITM091, False)
			' 補足項目９２
			db.setParam(sqlMTI_ASST1.prmASST_ITM092, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM092, pAsst1Rec.ASST_ITM092, False)
			' 補足項目９３
			db.setParam(sqlMTI_ASST1.prmASST_ITM093, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM093, pAsst1Rec.ASST_ITM093, False)
			' 補足項目９４
			db.setParam(sqlMTI_ASST1.prmASST_ITM094, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM094, pAsst1Rec.ASST_ITM094, False)
			' 補足項目９５
			db.setParam(sqlMTI_ASST1.prmASST_ITM095, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM095, pAsst1Rec.ASST_ITM095, False)
			' 補足項目９６
			db.setParam(sqlMTI_ASST1.prmASST_ITM096, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM096, pAsst1Rec.ASST_ITM096, False)
			' 補足項目９７
			db.setParam(sqlMTI_ASST1.prmASST_ITM097, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM097, pAsst1Rec.ASST_ITM097, False)
			' 補足項目９８
			db.setParam(sqlMTI_ASST1.prmASST_ITM098, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM098, pAsst1Rec.ASST_ITM098, False)
			' 補足項目９９
			db.setParam(sqlMTI_ASST1.prmASST_ITM099, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM099, pAsst1Rec.ASST_ITM099, False)
			' 補足項目１００
			db.setParam(sqlMTI_ASST1.prmASST_ITM100, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM100, pAsst1Rec.ASST_ITM100, False)
			' 補足項目１０１
			db.setParam(sqlMTI_ASST1.prmASST_ITM101, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM101, pAsst1Rec.ASST_ITM101, False)
			' 補足項目１０２
			db.setParam(sqlMTI_ASST1.prmASST_ITM102, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM102, pAsst1Rec.ASST_ITM102, False)
			' 補足項目１０３
			db.setParam(sqlMTI_ASST1.prmASST_ITM103, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM103, pAsst1Rec.ASST_ITM103, False)
			' 補足項目１０４
			db.setParam(sqlMTI_ASST1.prmASST_ITM104, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM104, pAsst1Rec.ASST_ITM104, False)
			' 補足項目１０５
			db.setParam(sqlMTI_ASST1.prmASST_ITM105, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM105, pAsst1Rec.ASST_ITM105, False)
			' 補足項目１０６
			db.setParam(sqlMTI_ASST1.prmASST_ITM106, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM106, pAsst1Rec.ASST_ITM106, False)
			' 補足項目１０７
			db.setParam(sqlMTI_ASST1.prmASST_ITM107, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM107, pAsst1Rec.ASST_ITM107, False)
			' 補足項目１０８
			db.setParam(sqlMTI_ASST1.prmASST_ITM108, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM108, pAsst1Rec.ASST_ITM108, False)
			' 補足項目１０９
			db.setParam(sqlMTI_ASST1.prmASST_ITM109, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM109, pAsst1Rec.ASST_ITM109, False)
			' 補足項目１１０
			db.setParam(sqlMTI_ASST1.prmASST_ITM110, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM110, pAsst1Rec.ASST_ITM110, False)
			' 補足項目１１１
			db.setParam(sqlMTI_ASST1.prmASST_ITM111, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM111, pAsst1Rec.ASST_ITM111, False)
			' 補足項目１１２
			db.setParam(sqlMTI_ASST1.prmASST_ITM112, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM112, pAsst1Rec.ASST_ITM112, False)
			' 補足項目１１３
			db.setParam(sqlMTI_ASST1.prmASST_ITM113, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM113, pAsst1Rec.ASST_ITM113, False)
			' 補足項目１１４
			db.setParam(sqlMTI_ASST1.prmASST_ITM114, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM114, pAsst1Rec.ASST_ITM114, False)
			' 補足項目１１５
			db.setParam(sqlMTI_ASST1.prmASST_ITM115, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM115, pAsst1Rec.ASST_ITM115, False)
			' 補足項目１１６
			db.setParam(sqlMTI_ASST1.prmASST_ITM116, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM116, pAsst1Rec.ASST_ITM116, False)
			' 補足項目１１７
			db.setParam(sqlMTI_ASST1.prmASST_ITM117, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM117, pAsst1Rec.ASST_ITM117, False)
			' 補足項目１１８
			db.setParam(sqlMTI_ASST1.prmASST_ITM118, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM118, pAsst1Rec.ASST_ITM118, False)
			' 補足項目１１９
			db.setParam(sqlMTI_ASST1.prmASST_ITM119, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM119, pAsst1Rec.ASST_ITM119, False)
			' 補足項目１２０
			db.setParam(sqlMTI_ASST1.prmASST_ITM120, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM120, pAsst1Rec.ASST_ITM120, False)
			' 補足項目１２１
			db.setParam(sqlMTI_ASST1.prmASST_ITM121, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM121, pAsst1Rec.ASST_ITM121, False)
			' 補足項目１２２
			db.setParam(sqlMTI_ASST1.prmASST_ITM122, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM122, pAsst1Rec.ASST_ITM122, False)
			' 補足項目１２３
			db.setParam(sqlMTI_ASST1.prmASST_ITM123, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM123, pAsst1Rec.ASST_ITM123, False)
			' 補足項目１２４
			db.setParam(sqlMTI_ASST1.prmASST_ITM124, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM124, pAsst1Rec.ASST_ITM124, False)
			' 補足項目１２５
			db.setParam(sqlMTI_ASST1.prmASST_ITM125, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM125, pAsst1Rec.ASST_ITM125, False)
			' 補足項目１２６
			db.setParam(sqlMTI_ASST1.prmASST_ITM126, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM126, pAsst1Rec.ASST_ITM126, False)
			' 補足項目１２７
			db.setParam(sqlMTI_ASST1.prmASST_ITM127, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM127, pAsst1Rec.ASST_ITM127, False)
			' 補足項目１２８
			db.setParam(sqlMTI_ASST1.prmASST_ITM128, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM128, pAsst1Rec.ASST_ITM128, False)
			' 補足項目１２９
			db.setParam(sqlMTI_ASST1.prmASST_ITM129, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM129, pAsst1Rec.ASST_ITM129, False)
			' 補足項目１３０
			db.setParam(sqlMTI_ASST1.prmASST_ITM130, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM130, pAsst1Rec.ASST_ITM130, False)
			' 補足項目１３１
			db.setParam(sqlMTI_ASST1.prmASST_ITM131, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM131, pAsst1Rec.ASST_ITM131, False)
			' 補足項目１３２
			db.setParam(sqlMTI_ASST1.prmASST_ITM132, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST1.prmASST_ITM132, pAsst1Rec.ASST_ITM132, False)
			' 更新者コード
			db.setParam(sqlMTI_ASST1.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
			If bLastUpdate OrElse String.IsNullOrEmpty(pAsst1Rec.LASTUPDUSER_CD) Then
				' 更新者コード←ログインＩＤ
				db.setVal(sqlMTI_ASST1.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
			Else
				db.setVal(sqlMTI_ASST1.prmLASTUPDUSER_CD, pAsst1Rec.LASTUPDUSER_CD)
			End If
			' 最終更新日
			db.setParam(sqlMTI_ASST1.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
			If bLastUpdate OrElse pAsst1Rec.LASTUPD_DT.Equals(Nothing) Then
				' 最終更新日←システム日付
				db.setVal(sqlMTI_ASST1.prmLASTUPD_DT, Now())
			Else
				db.setVal(sqlMTI_ASST1.prmLASTUPD_DT, pAsst1Rec.LASTUPD_DT)
			End If
			' 追加実行
			Return db.execNonQuery(False)
		Catch ex As Exception
			Throw
		End Try
	End Function
End Class
