﻿Imports XCM
Imports System.Reflection

''' ---------------------------------------------
''' <summary>
''' 共通処理_貸出情報クラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class clsMTI_LEND
	Implements IDisposable

#Region "解放処理"

	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2009/11/12 新規作成 CS)荒川<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2009/11/12 新規作成 CS)荒川<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2009/11/12 新規作成 CS)荒川<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

	''' ---------------------------------------------
	''' <summary>
	''' 貸出情報取得処理
	''' </summary>
	''' <param name="strPatient_No">患者番号</param>
	''' <param name="iHsp_History_No">入退院歴番号</param>
	''' <param name="iCh_No">科歴番号</param>
	''' <param name="eLendItem_Cd">貸出物コード</param>
	''' <param name="iLendSerial_No">貸出連番</param>
	''' <returns>貸出情報</returns>
	''' <remarks>
	''' 2010/10/26 新規作成　CS)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getDataFromPrimaryKey(ByVal strPatient_No As String, _
	  ByVal iHsp_History_No As Integer, _
	  ByVal iCh_No As Integer, _
	  ByVal eLendItem_Cd As clsConst.Enum_Lenditem, _
	  ByVal iLendSerial_No As Integer) As datMTI_LEND
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getDataFromPrimaryKey(db, strPatient_No, iHsp_History_No, iCh_No, eLendItem_Cd, iLendSerial_No)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 貸出情報取得処理
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <param name="strPatient_No">患者番号</param>
	''' <param name="iHsp_History_No">入退院歴番号</param>
	''' <param name="iCh_No">科歴番号</param>
	''' <param name="eLendItem_Cd">貸出物コード</param>
	''' <param name="iLendSerial_No">貸出連番</param>
	''' <returns>貸出情報</returns>
	''' <remarks>
	''' 2010/10/26 新規作成　CS)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getDataFromPrimaryKey(ByVal db As clsDB, _
	  ByVal strPatient_No As String, _
	  ByVal iHsp_History_No As Integer, _
	  ByVal iCh_No As Integer, _
	  ByVal eLendItem_Cd As clsConst.Enum_Lenditem, _
	  ByVal iLendSerial_No As Integer) As datMTI_LEND
		Dim iRet As Integer
		Dim arData As ArrayList = Nothing
		Try
			arData = New ArrayList()
			With db
				.setSQL(XSP.sqlMTI_LEND.sqlSel)	 'SELECT文設定
				' 患者番号
				.setParam(sqlMTI_LEND.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmPATIENT_NO, strPatient_No)
				' 入退院歴番号
				.setParam(sqlMTI_LEND.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LEND.prmHSP_HISTORY_NO, iHsp_History_No.ToString)
				' 科歴番号
				.setParam(sqlMTI_LEND.prmCH_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LEND.prmCH_NO, iCh_No.ToString)
				' 貸出物コード
				.setParam(sqlMTI_LEND.prmLENDITEM_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmLENDITEM_CD, CType(eLendItem_Cd, String))
				' 貸出連番
				.setParam(sqlMTI_LEND.prmLENDSERIAL_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LEND.prmLENDSERIAL_NO, iLendSerial_No.ToString)

				iRet = .execQuery(GetType(datMTI_LEND), arData)	 '値取得
			End With
			If iRet = 0 Then
				Return Nothing
			Else
				Return CType(arData(0), datMTI_LEND)
			End If
		Catch ex As Exception
			Throw
		Finally
			arData = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の貸出情報取得処理
	''' </summary>
	''' <param name="strPatient_No">患者番号</param>
	''' <param name="iHsp_History_No">入退院歴番号</param>
	''' <param name="iCh_No">科歴番号</param>
	''' <returns>１科歴分の貸出情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getDataFromChKey(ByVal strPatient_No As String, _
	  ByVal iHsp_History_No As Integer, _
	  ByVal iCh_No As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getDataFromChKey(db, strPatient_No, iHsp_History_No, iCh_No)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の貸出情報取得処理
	''' </summary>
	''' <param name="strPatient_No">患者番号</param>
	''' <param name="iHsp_History_No">入退院歴番号</param>
	''' <param name="iCh_No">科歴番号</param>
	''' <returns>１科歴分の貸出情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getDataFromChKey(ByVal db As clsDB, _
	  ByVal strPatient_No As String, _
	  ByVal iHsp_History_No As Integer, _
	  ByVal iCh_No As Integer) As ArrayList
		Dim iRet As Integer
		Dim arData As ArrayList = Nothing
		Try
			arData = New ArrayList()
			With db
				.setSQL(XSP.sqlMTI_LEND.sqlSelChKey)	 'SELECT文設定
				' 患者番号
				.setParam(sqlMTI_LEND.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmPATIENT_NO, strPatient_No)
				' 入退院歴番号
				.setParam(sqlMTI_LEND.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LEND.prmHSP_HISTORY_NO, iHsp_History_No.ToString)
				' 科歴番号
				.setParam(sqlMTI_LEND.prmCH_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LEND.prmCH_NO, iCh_No.ToString)

				iRet = .execQuery(GetType(datMTI_LEND), arData)	 '値取得
			End With
			Return arData
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 貸出中判定処理
	''' </summary>
	''' <param name="strPatient_No">患者番号</param>
	''' <param name="iHsp_History_No">入退院歴番号</param>
	''' <param name="iCh_No">科歴番号</param>
	''' <param name="eLendItem_Cd">貸出物コード</param>
	''' <returns></returns>
	''' <remarks>
	''' 2010/11/15 新規作成　CS)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function chkLending(ByVal strPatient_No As String, _
	  ByVal iHsp_History_No As Integer, _
	  ByVal iCh_No As Integer, _
	  ByVal eLendItem_Cd As clsConst.Enum_Lenditem) As Boolean
		Dim iRet As Integer
		Dim arData As ArrayList = Nothing
		Try
			arData = New ArrayList()
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				With db
					.setSQL(XSP.sqlMTI_LEND.sqlSelCheckLending)	 'SELECT文設定
					' 患者番号
					.setParam(sqlMTI_LEND.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
					.setVal(sqlMTI_LEND.prmPATIENT_NO, strPatient_No)
					' 入退院歴番号
					.setParam(sqlMTI_LEND.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
					.setVal(sqlMTI_LEND.prmHSP_HISTORY_NO, iHsp_History_No.ToString)
					' 科歴番号
					.setParam(sqlMTI_LEND.prmCH_NO, clsDB.Enum_dbType.dbInt)
					.setVal(sqlMTI_LEND.prmCH_NO, iCh_No.ToString)
					' 貸出物コード
					.setParam(sqlMTI_LEND.prmLENDITEM_CD, clsDB.Enum_dbType.dbNVarChar)
					.setVal(sqlMTI_LEND.prmLENDITEM_CD, CType(eLendItem_Cd, String))

					iRet = .execQuery(GetType(datMTI_LEND_CheckLending), arData)	 '値取得
				End With
			End Using
			If iRet = 0 Then
				' 保管中
				Return False
			Else
				' 貸出中
				Return True
			End If
		Catch ex As Exception
			Throw
		Finally
			arData = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 返却予定日計算
	''' </summary>
	''' <param name="strLendAim_Cd">貸出目的コード</param>
	''' <param name="strIssue_Dt">貸出日</param>
	''' <param name="strLendDays">貸出日数</param>
	''' <returns></returns>
	''' <remarks>
	''' 2010/10/26 新規作成　CS)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getExpectBack_Dt(ByVal strLendAim_Cd As String, _
	  ByVal strIssue_Dt As String, _
	  ByVal strLendDays As String) As String
		Try
			If String.IsNullOrEmpty(strLendAim_Cd) Then Return String.Empty
			If String.IsNullOrEmpty(strIssue_Dt) Then Return String.Empty
			If Not IsDate(strIssue_Dt) Then Return String.Empty
			If Not IsNumeric(strLendDays) Then Return String.Empty
			If CInt(strLendDays) = clsConst.CST_LENDDAYS_MAX Then Return Nothing
			' 日付計算
			Return CDate(strIssue_Dt).AddDays(CInt(strLendDays))
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 伝票番号取得処理
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <returns></returns>
	''' <remarks>
	''' 2010/10/27 新規作成　CS)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getSlip_Cd(ByVal db As clsDB) As String
		Dim strSlipCD As String = ""
		Dim iNo As Integer = 0
'(M) STR V4-11044-000 004 20110909 FJSK)荒川 XXX号 病歴大将V4PKG問題点No20 貸出準備機能の追加対応
'		Dim dtNow As Date = Now.ToString("yyyy/MM/dd")
		Dim dtNow As Date = Now.ToString(clsConst.CST_YYYYMMDD_FORMAT)
'(M) END V4-11044-000 004 20110909
		Dim arData As ArrayList = Nothing
		Try
			arData = New ArrayList()
			With db
				Try
					.setSQL(sqlMTI_LEND.strSqlMaxSlipCD)
					' 管理物コード
					.setParam(sqlMTI_LEND.prmSLIP_CD_YYMM, clsDB.Enum_dbType.dbNVarChar)
					.setVal(sqlMTI_LEND.prmSLIP_CD_YYMM, sqlMTI_LEND.C_SLIP_CD_1 & dtNow.ToString("yyMM") & "%")
					' 取得
					.execQuery(GetType(datSlip_Cd), arData)

				Catch ex As Exception
					Throw
				End Try
			End With
			Dim dat As datSlip_Cd = arData(0)

			If dat.SLIP_CD.Substring(1, 4) = dtNow.ToString("yyMM") Then
				If CType(dat.SLIP_CD.Substring(6, 4), Integer) = sqlMTI_LEND.C_SLIP_CD_MAX Then
					strSlipCD = sqlMTI_LEND.C_SLIP_CD_MAXOVER
				Else
					iNo = CType(dat.SLIP_CD.Substring(6, 4), Integer) + 1
					strSlipCD = dat.SLIP_CD.Substring(0, 6) & Format(iNo, "0000")
				End If
			Else
				strSlipCD = dat.SLIP_CD.Substring(0, 1) & dtNow.ToString("yyMM") & sqlMTI_LEND.C_SLIP_CD_MIN
			End If
		Catch ex As Exception
			Throw
		Finally
			arData = Nothing
		End Try
		Return strSlipCD
	End Function

'(A) STR V4-11044-000 051 20110909 FJSK)荒川 XXX号 病歴大将V4PKG問題点No20 貸出準備機能の追加対応
	''' ---------------------------------------------
	''' <summary>
	''' 準備番号取得処理
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <returns></returns>
	''' <remarks>
	''' 2011/09/21 新規作成 FJSK)荒川<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getRSlip_Cd(ByVal db As clsDB) As String
		Dim strSlipCD As String = ""
		Dim iNo As Integer = 0
		Dim dtNow As Date = Now.ToString(clsConst.CST_YYYYMMDD_FORMAT)
		Dim arData As ArrayList = Nothing
		Try
			arData = New ArrayList()
			With db
				Try
					.setSQL(sqlMTI_LEND.strSqlMaxRSlipCD)
					' 管理物コード
					.setParam(sqlMTI_LEND.prmSLIP_CD_YYMM, clsDB.Enum_dbType.dbNVarChar)
					.setVal(sqlMTI_LEND.prmSLIP_CD_YYMM, sqlMTI_LEND.C_RSLIP_CD_1 & dtNow.ToString("yyMM") & "%")
					' 取得
					.execQuery(GetType(datSlip_Cd), arData)

				Catch ex As Exception
					Throw
				End Try
			End With
			Dim dat As datSlip_Cd = arData(0)

			If dat.SLIP_CD.Substring(1, 4) = dtNow.ToString("yyMM") Then
				If CType(dat.SLIP_CD.Substring(6, 4), Integer) = sqlMTI_LEND.C_SLIP_CD_MAX Then
					strSlipCD = sqlMTI_LEND.C_SLIP_CD_MAXOVER
				Else
					iNo = CType(dat.SLIP_CD.Substring(6, 4), Integer) + 1
					strSlipCD = dat.SLIP_CD.Substring(0, 6) & Format(iNo, "0000")
				End If
			Else
				strSlipCD = dat.SLIP_CD.Substring(0, 1) & dtNow.ToString("yyMM") & sqlMTI_LEND.C_SLIP_CD_MIN
			End If
		Catch ex As Exception
			Throw
		Finally
			arData = Nothing
		End Try
		Return strSlipCD
	End Function
'(A) END V4-11044-000 051 20110909
	''' ---------------------------------------------
	''' <summary>
	''' 貸出情報最大連番取得
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <param name="strPatient_No">患者番号</param>
	''' <param name="iHsp_History_No">入退院歴番号</param>
	''' <param name="iCh_No">科歴番号</param>
	''' <param name="strLendItem_Cd">貸出物コード</param>
	''' <returns></returns>
	''' <remarks>
	''' 2010/10/27 新規作成　CS)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getLendSerialNo(ByVal db As clsDB, _
	  ByVal strPatient_No As String, _
	  ByVal iHsp_History_No As Integer, _
	  ByVal iCh_No As Integer, _
	  ByVal strLendItem_Cd As String) As datLendSerialNo
		Dim iRet As Integer
		Dim arData As ArrayList = Nothing
		Dim retDat As datLendSerialNo = Nothing
		Try
			arData = New ArrayList()
			retDat = New datLendSerialNo
			With db
				Try
					.setSQL(sqlMTI_LEND.strSqlMaxLendSerialNo)
					' 患者番号
					.setParam(sqlMTI_LEND.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
					.setVal(sqlMTI_LEND.prmPATIENT_NO, strPatient_No)
					' 入退院歴番号
					.setParam(sqlMTI_LEND.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
					.setVal(sqlMTI_LEND.prmHSP_HISTORY_NO, iHsp_History_No.ToString)
					' 科歴番号
					.setParam(sqlMTI_LEND.prmCH_NO, clsDB.Enum_dbType.dbInt)
					.setVal(sqlMTI_LEND.prmCH_NO, iCh_No.ToString)
					' 貸出物コード
					.setParam(sqlMTI_LEND.prmLENDITEM_CD, clsDB.Enum_dbType.dbNVarChar)
					.setVal(sqlMTI_LEND.prmLENDITEM_CD, strLendItem_Cd)

					iRet = .execQuery(GetType(datLendSerialNo), arData)

				Catch ex As Exception
					Throw
				End Try
			End With
			If iRet = 0 Then
				retDat = Nothing
			Else
				retDat = CType(arData(0), datLendSerialNo)
			End If
		Catch ex As Exception
			Throw
		Finally
			arData = Nothing
		End Try
		Return retDat
	End Function

'(A) STR V4-11044-000 061 20110909 FJSK)荒川 XXX号 病歴大将V4PKG問題点No20 貸出準備機能の追加対応
	''' ---------------------------------------------
	''' <summary>
	''' 貸出情報最大連番取得
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <param name="strPatient_No">患者番号</param>
	''' <param name="iHsp_History_No">入退院歴番号</param>
	''' <param name="iCh_No">科歴番号</param>
	''' <param name="strLendItem_Cd">貸出物コード</param>
	''' <returns></returns>
	''' <remarks>
	''' 2010/10/27 新規作成　CS)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getLendPrepareSerialNo(ByVal db As clsDB, _
	  ByVal strPatient_No As String, _
	  ByVal iHsp_History_No As Integer, _
	  ByVal iCh_No As Integer, _
	  ByVal strLendItem_Cd As String) As datLendPrepareSerialNo
		Dim iRet As Integer
		Dim arData As ArrayList = Nothing
		Dim retDat As datLendPrepareSerialNo = Nothing
		Try
			arData = New ArrayList()
			retDat = New datLendPrepareSerialNo
			With db
				Try
					.setSQL(sqlMTI_LEND.strSqlMaxLendPrepareSerialNo)
					' 患者番号
					.setParam(sqlMTI_LEND.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
					.setVal(sqlMTI_LEND.prmPATIENT_NO, strPatient_No)
					' 入退院歴番号
					.setParam(sqlMTI_LEND.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
					.setVal(sqlMTI_LEND.prmHSP_HISTORY_NO, iHsp_History_No.ToString)
					' 科歴番号
					.setParam(sqlMTI_LEND.prmCH_NO, clsDB.Enum_dbType.dbInt)
					.setVal(sqlMTI_LEND.prmCH_NO, iCh_No.ToString)
					' 貸出物コード
					.setParam(sqlMTI_LEND.prmLENDITEM_CD, clsDB.Enum_dbType.dbNVarChar)
					.setVal(sqlMTI_LEND.prmLENDITEM_CD, strLendItem_Cd)

					iRet = .execQuery(GetType(datLendPrepareSerialNo), arData)

				Catch ex As Exception
					Throw
				End Try
			End With
			If iRet = 0 Then
				retDat = Nothing
			Else
				retDat = CType(arData(0), datLendPrepareSerialNo)
			End If
		Catch ex As Exception
			Throw
		Finally
			arData = Nothing
		End Try
		Return retDat
	End Function
'(A) END V4-11044-000 061 20110909
	''' ---------------------------------------------
	''' <summary>
	''' 貸出情報取得処理（Record Lock）
	''' </summary>
	''' <param name="strPatient_No">患者番号</param>
	''' <param name="iHsp_History_No">入退院歴番号</param>
	''' <param name="iCh_No">科歴番号</param>
	''' <param name="eLendItem_Cd">貸出物コード</param>
	''' <param name="iLendSerial_No">貸出連番</param>
	''' <returns>貸出情報</returns>
	''' <remarks>
	''' 2010/10/26 新規作成　CS)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getDataFromPrimaryKeyLock(ByVal strPatient_No As String, _
	  ByVal iHsp_History_No As Integer, _
	  ByVal iCh_No As Integer, _
	  ByVal eLendItem_Cd As clsConst.Enum_Lenditem, _
	  ByVal iLendSerial_No As Integer) As Integer
		Dim iRet As Integer
		Dim arData As ArrayList = Nothing
		Try
			arData = New ArrayList()
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				With db
					.setSQL(XSP.sqlMTI_LEND.sqlSelLock)	 'SELECT文設定
					' 患者番号
					.setParam(sqlMTI_LEND.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
					.setVal(sqlMTI_LEND.prmPATIENT_NO, strPatient_No)
					' 入退院歴番号
					.setParam(sqlMTI_LEND.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
					.setVal(sqlMTI_LEND.prmHSP_HISTORY_NO, iHsp_History_No.ToString)
					' 科歴番号
					.setParam(sqlMTI_LEND.prmCH_NO, clsDB.Enum_dbType.dbInt)
					.setVal(sqlMTI_LEND.prmCH_NO, iCh_No.ToString)
					' 貸出物コード
					.setParam(sqlMTI_LEND.prmLENDITEM_CD, clsDB.Enum_dbType.dbNVarChar)
					.setVal(sqlMTI_LEND.prmLENDITEM_CD, CType(eLendItem_Cd, String))
					' 貸出連番
					.setParam(sqlMTI_LEND.prmLENDSERIAL_NO, clsDB.Enum_dbType.dbInt)
					.setVal(sqlMTI_LEND.prmLENDSERIAL_NO, iLendSerial_No.ToString)

					iRet = .execQuery(GetType(datMTI_LEND_LOCK), arData)	 '値取得
				End With
			End Using
			Return iRet
		Catch ex As Exception
			Throw
		Finally
			arData = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 貸出情報登録処理（貸出処理）
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <param name="dat">貸出情報受渡しクラス</param>
	''' <returns></returns>
	''' <remarks>
	''' 2010/10/28 新規作成　CS)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function addLend(ByVal db As clsDB, _
	  ByVal dat As datMTI_LEND) As Integer
		Try
			Return addLend(db, dat, True)
		Catch ex As SqlClient.SqlException
			Throw
		Catch ex As Exception
			Throw
		End Try
	End Function

'(A) STR V4-11044-000 021 20110909 FJSK)荒川 XXX号 病歴大将V4PKG問題点No20 貸出準備機能の追加対応
	''' ---------------------------------------------
	''' <summary>
	''' 貸出準備情報登録処理（貸出準備処理）
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <param name="dat">貸出情報受渡しクラス</param>
	''' <returns></returns>
	''' <remarks>
	''' 2011/09/21 新規作成 FJSK)荒川<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function addLendPrepare(ByVal db As clsDB, _
	  ByVal dat As datMTI_LEND) As Integer
		Try
			Return addLendPrepare(db, dat, True)
		Catch ex As SqlClient.SqlException
			Throw
		Catch ex As Exception
			Throw
		End Try
	End Function
'(A) END V4-11044-000 021 20110909
	''' ---------------------------------------------
	''' <summary>
	''' 貸出情報登録処理（貸出処理）
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <param name="dat">貸出情報受渡しクラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <returns></returns>
	''' <remarks>
	''' 2010/10/28 新規作成　CS)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function addLend(ByVal db As clsDB, _
	  ByVal dat As datMTI_LEND, _
	  ByVal bLastUpdate As Boolean) As Integer
		Dim iRet As Integer
		Try
			With db
				.setSQL(sqlMTI_LEND.sqlAddLend)
				' ■カルテ更新
				' 患者番号
				.setParam(sqlMTI_LENDITM.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LENDITM.prmPATIENT_NO, dat.PATIENT_NO)
				' 入退院歴番号
				.setParam(sqlMTI_LENDITM.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LENDITM.prmHSP_HISTORY_NO, dat.HSP_HISTORY_NO.ToString)
				' 科歴番号
				.setParam(sqlMTI_LENDITM.prmCH_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LENDITM.prmCH_NO, dat.CH_NO.ToString)

				' 貸出物コード
				.setParam(sqlMTI_LEND.prmLENDITEM_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmLENDITEM_CD, dat.LENDITEM_CD)
				' 貸出連番
				.setParam(sqlMTI_LEND.prmLENDSERIAL_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LEND.prmLENDSERIAL_NO, dat.LENDSERIAL_NO.ToString)
				' 伝票コード
				.setParam(sqlMTI_LEND.prmSLIP_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmSLIP_CD, dat.SLIP_CD)
				' 貸出目的コード
				.setParam(sqlMTI_LEND.prmLENDAIM_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmLENDAIM_CD, dat.LENDAIM_CD)
				' 所在場所コード
				.setParam(sqlMTI_LEND.prmLCT_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmLCT_CD, dat.LCT_CD)
				' 貸出日
				.setParam(sqlMTI_LEND.prmISSUE_DT, clsDB.Enum_dbType.dbDateTime)
				.setVal(sqlMTI_LEND.prmISSUE_DT, dat.ISSUE_DT)
				' 返却予定日
				.setParam(sqlMTI_LEND.prmEXPECTBACK_DT, clsDB.Enum_dbType.dbDateTime)
				.setVal(sqlMTI_LEND.prmEXPECTBACK_DT, dat.EXPECTBACK_DT)
				' 借用者部門コード
				.setParam(sqlMTI_LEND.prmBORROWER_DIV, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmBORROWER_DIV, dat.BORROWER_DIV)
				' 借用者コード
				.setParam(sqlMTI_LEND.prmBORROWER_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmBORROWER_CD, dat.BORROWER_CD)
				' 借用者名
				.setParam(sqlMTI_LEND.prmBORROWER_NM, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmBORROWER_NM, dat.BORROWER_NM)
				' 帯出者部門コード
				.setParam(sqlMTI_LEND.prmTAKER_DIV, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmTAKER_DIV, dat.TAKER_DIV)
				' 帯出者コード
				.setParam(sqlMTI_LEND.prmTAKER_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmTAKER_CD, dat.TAKER_CD)
				' 帯出者名
				.setParam(sqlMTI_LEND.prmTAKER_NM, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmTAKER_NM, dat.TAKER_NM)
				' 貸出取扱者コード
				.setParam(sqlMTI_LEND.prmLENDCLERK_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmLENDCLERK_CD, dat.LENDCLERK_CD)
				' 備考
				.setParam(sqlMTI_LEND.prmREMARKS, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmREMARKS, dat.REMARKS)

				' 更新者コード
				.setParam(sqlMTI_LENDITM.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
				If bLastUpdate OrElse String.IsNullOrEmpty(dat.LASTUPDUSER_CD) Then
					' 更新者コード←ログインＩＤ
					.setVal(sqlMTI_LEND.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
				Else
					.setVal(sqlMTI_LENDITM.prmLASTUPDUSER_CD, dat.LASTUPDUSER_CD)
				End If
				' 最終更新日
				db.setParam(sqlMTI_LEND.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
				If bLastUpdate OrElse dat.LASTUPD_DT.Equals(Nothing) Then
					' 最終更新日←システム日付
					.setVal(sqlMTI_LENDITM.prmLASTUPD_DT, Now)
				Else
					.setVal(sqlMTI_LEND.prmLASTUPD_DT, dat.LASTUPD_DT)
				End If

				iRet = .execNonQuery(False)
			End With
			Return iRet
		Catch ex As SqlClient.SqlException
			Throw
		Catch ex As Exception
			Throw
		End Try
	End Function

'(A) STR V4-11044-000 103 20110909 FJSK)荒川 XXX号 病歴大将V4PKG問題点No20 貸出準備機能の追加対応
	''' ---------------------------------------------
	''' <summary>
	''' 貸出準備情報登録処理（貸出処理）
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <param name="dat">貸出情報受渡しクラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <returns></returns>
	''' <remarks>
	''' 2010/10/28 新規作成　CS)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function addLendPrepare(ByVal db As clsDB, _
	  ByVal dat As datMTI_LEND, _
	  ByVal bLastUpdate As Boolean) As Integer
		Dim iRet As Integer
		Try
			With db
				.setSQL(sqlMTI_LEND.sqlAddLendPrepare)
				' ■カルテ更新
				' 患者番号
				.setParam(sqlMTI_LENDITM.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LENDITM.prmPATIENT_NO, dat.PATIENT_NO)
				' 入退院歴番号
				.setParam(sqlMTI_LENDITM.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LENDITM.prmHSP_HISTORY_NO, dat.HSP_HISTORY_NO.ToString)
				' 科歴番号
				.setParam(sqlMTI_LENDITM.prmCH_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LENDITM.prmCH_NO, dat.CH_NO.ToString)

				' 貸出物コード
				.setParam(sqlMTI_LEND.prmLENDITEM_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmLENDITEM_CD, dat.LENDITEM_CD)
				' 貸出連番
				.setParam(sqlMTI_LEND.prmLENDSERIAL_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LEND.prmLENDSERIAL_NO, dat.LENDSERIAL_NO.ToString)
				' 伝票コード
				.setParam(sqlMTI_LEND.prmSLIP_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmSLIP_CD, dat.SLIP_CD)
				' 貸出目的コード
				.setParam(sqlMTI_LEND.prmLENDAIM_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmLENDAIM_CD, dat.LENDAIM_CD)
				' 所在場所コード
				.setParam(sqlMTI_LEND.prmLCT_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmLCT_CD, dat.LCT_CD)
				' 貸出日
				.setParam(sqlMTI_LEND.prmISSUE_DT, clsDB.Enum_dbType.dbDateTime)
				.setVal(sqlMTI_LEND.prmISSUE_DT, dat.ISSUE_DT)
				' 返却予定日
				.setParam(sqlMTI_LEND.prmEXPECTBACK_DT, clsDB.Enum_dbType.dbDateTime)
				.setVal(sqlMTI_LEND.prmEXPECTBACK_DT, dat.EXPECTBACK_DT)
				' 借用者部門コード
				.setParam(sqlMTI_LEND.prmBORROWER_DIV, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmBORROWER_DIV, dat.BORROWER_DIV)
				' 借用者コード
				.setParam(sqlMTI_LEND.prmBORROWER_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmBORROWER_CD, dat.BORROWER_CD)
				' 借用者名
				.setParam(sqlMTI_LEND.prmBORROWER_NM, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmBORROWER_NM, dat.BORROWER_NM)
				' 帯出者部門コード
				.setParam(sqlMTI_LEND.prmTAKER_DIV, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmTAKER_DIV, dat.TAKER_DIV)
				' 帯出者コード
				.setParam(sqlMTI_LEND.prmTAKER_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmTAKER_CD, dat.TAKER_CD)
				' 帯出者名
				.setParam(sqlMTI_LEND.prmTAKER_NM, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmTAKER_NM, dat.TAKER_NM)
				' 貸出取扱者コード
				.setParam(sqlMTI_LEND.prmLENDCLERK_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmLENDCLERK_CD, dat.LENDCLERK_CD)
				' 備考
				.setParam(sqlMTI_LEND.prmREMARKS, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmREMARKS, dat.REMARKS)

				' 更新者コード
				.setParam(sqlMTI_LENDITM.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
				If bLastUpdate OrElse String.IsNullOrEmpty(dat.LASTUPDUSER_CD) Then
					' 更新者コード←ログインＩＤ
					.setVal(sqlMTI_LEND.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
				Else
					.setVal(sqlMTI_LENDITM.prmLASTUPDUSER_CD, dat.LASTUPDUSER_CD)
				End If
				' 最終更新日
				db.setParam(sqlMTI_LEND.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
				If bLastUpdate OrElse dat.LASTUPD_DT.Equals(Nothing) Then
					' 最終更新日←システム日付
					.setVal(sqlMTI_LENDITM.prmLASTUPD_DT, Now)
				Else
					.setVal(sqlMTI_LEND.prmLASTUPD_DT, dat.LASTUPD_DT)
				End If

				iRet = .execNonQuery(False)
			End With
			Return iRet
		Catch ex As SqlClient.SqlException
			Throw
		Catch ex As Exception
			Throw
		End Try
	End Function
'(A) END V4-11044-000 103 20110909
	''' ---------------------------------------------
	''' <summary>
	''' 貸出情報更新処理（返却処理）
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <param name="dat">貸出情報受渡しクラス</param>
	''' <returns></returns>
	''' <remarks>
	''' 2010/10/28 新規作成　CS)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function updBack(ByVal db As clsDB, _
	  ByVal dat As datMTI_LEND) As Integer
		Dim iRet As Integer
		Try
			With db
				.setSQL(sqlMTI_LEND.sqlUpdBack)
				' ■カルテ更新
				' 患者番号
				.setParam(sqlMTI_LENDITM.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LENDITM.prmPATIENT_NO, dat.PATIENT_NO)
				' 入退院歴番号
				.setParam(sqlMTI_LENDITM.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LENDITM.prmHSP_HISTORY_NO, dat.HSP_HISTORY_NO.ToString)
				' 科歴番号
				.setParam(sqlMTI_LENDITM.prmCH_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LENDITM.prmCH_NO, dat.CH_NO.ToString)
				' 貸出物コード
				.setParam(sqlMTI_LEND.prmLENDITEM_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmLENDITEM_CD, dat.LENDITEM_CD)
				' 貸出連番
				.setParam(sqlMTI_LEND.prmLENDSERIAL_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LEND.prmLENDSERIAL_NO, dat.LENDSERIAL_NO.ToString)

				' 返却日
				.setParam(sqlMTI_LEND.prmBACK_DT, clsDB.Enum_dbType.dbDateTime)
				.setVal(sqlMTI_LEND.prmBACK_DT, dat.BACK_DT)
				' 返却取扱者コード
				.setParam(sqlMTI_LEND.prmBACKCLERK_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmBACKCLERK_CD, dat.BACKCLERK_CD)

				' 更新者コード
				.setParam(sqlMTI_LENDITM.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LENDITM.prmLASTUPDUSER_CD, dat.LASTUPDUSER_CD)
				' 更新日
				.setParam(sqlMTI_LENDITM.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
				.setVal(sqlMTI_LENDITM.prmLASTUPD_DT, Now)

				iRet = .execNonQuery(False)
			End With
			Return iRet
		Catch ex As SqlClient.SqlException
			Throw
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 貸出情報更新処理（貸出更新処理）
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <param name="dat">貸出情報受渡しクラス</param>
	''' <returns></returns>
	''' <remarks>
	''' 2010/10/28 新規作成　CS)平井<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function updLendUpd(ByVal db As clsDB, _
	  ByVal dat As datMTI_LEND) As Integer
		Dim iRet As Integer
		Try
			With db
				.setSQL(sqlMTI_LEND.sqlLendUpd)
				' ■カルテ更新
				' 患者番号
				.setParam(sqlMTI_LENDITM.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LENDITM.prmPATIENT_NO, dat.PATIENT_NO)
				' 入退院歴番号
				.setParam(sqlMTI_LENDITM.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LENDITM.prmHSP_HISTORY_NO, dat.HSP_HISTORY_NO.ToString)
				' 科歴番号
				.setParam(sqlMTI_LENDITM.prmCH_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LENDITM.prmCH_NO, dat.CH_NO.ToString)

				' 貸出物コード
				.setParam(sqlMTI_LEND.prmLENDITEM_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmLENDITEM_CD, dat.LENDITEM_CD)
				' 貸出連番
				.setParam(sqlMTI_LEND.prmLENDSERIAL_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LEND.prmLENDSERIAL_NO, dat.LENDSERIAL_NO.ToString)
				' 貸出目的コード
				.setParam(sqlMTI_LEND.prmLENDAIM_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmLENDAIM_CD, dat.LENDAIM_CD)
				' 所在場所コード
				.setParam(sqlMTI_LEND.prmLCT_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmLCT_CD, dat.LCT_CD)
				' 貸出日
				.setParam(sqlMTI_LEND.prmISSUE_DT, clsDB.Enum_dbType.dbDateTime)
				.setVal(sqlMTI_LEND.prmISSUE_DT, dat.ISSUE_DT)
				' 返却予定日
				.setParam(sqlMTI_LEND.prmEXPECTBACK_DT, clsDB.Enum_dbType.dbDateTime)
				.setVal(sqlMTI_LEND.prmEXPECTBACK_DT, dat.EXPECTBACK_DT)
				' 借用者部門コード
				.setParam(sqlMTI_LEND.prmBORROWER_DIV, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmBORROWER_DIV, dat.BORROWER_DIV)
				' 借用者コード
				.setParam(sqlMTI_LEND.prmBORROWER_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmBORROWER_CD, dat.BORROWER_CD)
				' 借用者名
				.setParam(sqlMTI_LEND.prmBORROWER_NM, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmBORROWER_NM, dat.BORROWER_NM)
				' 帯出者部門コード
				.setParam(sqlMTI_LEND.prmTAKER_DIV, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmTAKER_DIV, dat.TAKER_DIV)
				' 帯出者コード
				.setParam(sqlMTI_LEND.prmTAKER_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmTAKER_CD, dat.TAKER_CD)
				' 帯出者名
				.setParam(sqlMTI_LEND.prmTAKER_NM, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmTAKER_NM, dat.TAKER_NM)
				' 貸出取扱者コード
				.setParam(sqlMTI_LEND.prmLENDCLERK_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmLENDCLERK_CD, dat.LENDCLERK_CD)
				' 備考
				.setParam(sqlMTI_LEND.prmREMARKS, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmREMARKS, dat.REMARKS)

				' 更新者コード
				.setParam(sqlMTI_LENDITM.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LENDITM.prmLASTUPDUSER_CD, dat.LASTUPDUSER_CD)
				' 更新日
				.setParam(sqlMTI_LENDITM.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
				.setVal(sqlMTI_LENDITM.prmLASTUPD_DT, Now)

				iRet = .execNonQuery(False)
			End With
			Return iRet
		Catch ex As SqlClient.SqlException
			Throw
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 貸出情報取得処理（Record Lock）
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <param name="strPatient_No">患者番号</param>
	''' <param name="iHsp_History_No">入退院歴番号</param>
	''' <param name="iCh_No">科歴番号</param>
	''' <param name="eLendItem_Cd">貸出物コード</param>
	''' <param name="iLendSerial_No">貸出連番</param>
	''' <returns>貸出情報</returns>
	''' <remarks>
	''' 2010/11/17 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getDataFromPrimaryKeyLock(ByRef db As clsDB, _
	  ByVal strPatient_No As String, _
	  ByVal iHsp_History_No As Integer, _
	  ByVal iCh_No As Integer, _
	  ByVal eLendItem_Cd As clsConst.Enum_Lenditem, _
	  ByVal iLendSerial_No As Integer) As datMTI_LEND
		Dim iRet As Integer
		Dim arData As ArrayList = Nothing
		Try
			arData = New ArrayList()
			With db
				.setSQL(XSP.sqlMTI_LEND.sqlSelAllItmForLock)	 'SELECT文設定
				' 患者番号
				.setParam(sqlMTI_LEND.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmPATIENT_NO, strPatient_No)
				' 入退院歴番号
				.setParam(sqlMTI_LEND.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LEND.prmHSP_HISTORY_NO, iHsp_History_No.ToString)
				' 科歴番号
				.setParam(sqlMTI_LEND.prmCH_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LEND.prmCH_NO, iCh_No.ToString)
				' 貸出物コード
				.setParam(sqlMTI_LEND.prmLENDITEM_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmLENDITEM_CD, CType(eLendItem_Cd, String))
				' 貸出連番
				.setParam(sqlMTI_LEND.prmLENDSERIAL_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LEND.prmLENDSERIAL_NO, iLendSerial_No.ToString)

				iRet = .execQuery(GetType(datMTI_LEND), arData, False)	  '値取得
			End With
			If iRet = 0 Then
				Return Nothing
			Else
				Return CType(arData(0), datMTI_LEND)
			End If
		Catch ex As Exception
			Throw
		Finally
			arData = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 貸出情報更新処理（返却督促処理）
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <param name="dat">貸出情報受渡しクラス</param>
	''' <returns></returns>
	''' <remarks>
	''' 2010/11/17 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function updUrgedBack(ByRef db As clsDB, _
	  ByVal dat As datMTI_LEND) As Integer
		Dim iRet As Integer
		Try
			With db
				.setSQL(sqlMTI_LEND.sqlUpdUrgedBack)
				' ■カルテ更新
				' 患者番号
				.setParam(sqlMTI_LENDITM.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LENDITM.prmPATIENT_NO, dat.PATIENT_NO)
				' 入退院歴番号
				.setParam(sqlMTI_LENDITM.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LENDITM.prmHSP_HISTORY_NO, dat.HSP_HISTORY_NO.ToString)
				' 科歴番号
				.setParam(sqlMTI_LENDITM.prmCH_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LENDITM.prmCH_NO, dat.CH_NO.ToString)
				' 貸出物コード
				.setParam(sqlMTI_LEND.prmLENDITEM_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmLENDITEM_CD, dat.LENDITEM_CD)
				' 貸出連番
				.setParam(sqlMTI_LEND.prmLENDSERIAL_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LEND.prmLENDSERIAL_NO, dat.LENDSERIAL_NO.ToString)

				' 返却督促日
				.setParam(sqlMTI_LEND.prmURGEDBACK_DT, clsDB.Enum_dbType.dbDateTime)
				.setVal(sqlMTI_LEND.prmURGEDBACK_DT, dat.URGEDBACK_DT)

				' 更新者コード
				.setParam(sqlMTI_LENDITM.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LENDITM.prmLASTUPDUSER_CD, dat.LASTUPDUSER_CD)
				' 更新日
				.setParam(sqlMTI_LENDITM.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
				.setVal(sqlMTI_LENDITM.prmLASTUPD_DT, Now)

				iRet = .execNonQuery(False)
			End With
			Return iRet
		Catch ex As SqlClient.SqlException
			Throw
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 貸出情報更新処理（返納督促準備処理）
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <param name="dat">貸出情報受渡しクラス</param>
	''' <returns></returns>
	''' <remarks>
	''' 2010/11/17 新規作成　CS)松本<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function updExpectBack(ByRef db As clsDB, _
	  ByVal dat As datMTI_LEND) As Integer
		Dim iRet As Integer
		Try
			With db
				.setSQL(sqlMTI_LEND.sqlUpdExpectBack)
				' ■カルテ更新
				' 患者番号
				.setParam(sqlMTI_LENDITM.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LENDITM.prmPATIENT_NO, dat.PATIENT_NO)
				' 入退院歴番号
				.setParam(sqlMTI_LENDITM.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LENDITM.prmHSP_HISTORY_NO, dat.HSP_HISTORY_NO.ToString)
				' 科歴番号
				.setParam(sqlMTI_LENDITM.prmCH_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LENDITM.prmCH_NO, dat.CH_NO.ToString)
				' 貸出物コード
				.setParam(sqlMTI_LEND.prmLENDITEM_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LEND.prmLENDITEM_CD, dat.LENDITEM_CD)
				' 貸出連番
				.setParam(sqlMTI_LEND.prmLENDSERIAL_NO, clsDB.Enum_dbType.dbInt)
				.setVal(sqlMTI_LEND.prmLENDSERIAL_NO, dat.LENDSERIAL_NO.ToString)

				' 返却予定日
				.setParam(sqlMTI_LEND.prmEXPECTBACK_DT, clsDB.Enum_dbType.dbDateTime)
				.setVal(sqlMTI_LEND.prmEXPECTBACK_DT, dat.EXPECTBACK_DT)

				' 更新者コード
				.setParam(sqlMTI_LENDITM.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
				.setVal(sqlMTI_LENDITM.prmLASTUPDUSER_CD, dat.LASTUPDUSER_CD)
				' 更新日
				.setParam(sqlMTI_LENDITM.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
				.setVal(sqlMTI_LENDITM.prmLASTUPD_DT, Now)

				iRet = .execNonQuery(False)
			End With
			Return iRet
		Catch ex As SqlClient.SqlException
			Throw
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の貸出情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelLendPatient(ByVal db As clsDB, _
	  ByVal pPatientNo As String)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "貸出情報アクセスクラス", "１患者分の貸出情報を削除 Start")
		Try
			'キーチェック
			If Not String.IsNullOrWhiteSpace(pPatientNo) Then
				' 削除実行
				db.setSQL(sqlMTI_LEND.sqlDelLend_Patient)	'DELETE文設定
				db.setParam(sqlMTI_LEND.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setVal(sqlMTI_LEND.prmPATIENT_NO, pPatientNo)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の貸出情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelLendHsp(ByVal db As clsDB, _
	  ByVal pPatientNo As String, _
	  ByVal pHspHistoryNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "貸出情報アクセスクラス", "１入退院分の貸出情報を削除 Start")
		Try
			'キーチェック
			If Not String.IsNullOrWhiteSpace(pPatientNo) AndAlso _
			 pHspHistoryNo > 0 Then
				' 削除実行
				db.setSQL(sqlMTI_LEND.sqlDelLend_Hsp)	'DELETE文設定
				db.setParam(sqlMTI_LEND.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_LEND.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setVal(sqlMTI_LEND.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_LEND.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の貸出情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelLendCh(ByVal db As clsDB, _
	  ByVal pPatientNo As String, _
	  ByVal pHspHistoryNo As Integer, _
	  ByVal pChNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "貸出情報アクセスクラス", "１科歴分の貸出情報を削除 Start")
		Try
			'キーチェック
			If Not String.IsNullOrWhiteSpace(pPatientNo) AndAlso _
			 pHspHistoryNo > 0 AndAlso _
			 pChNo > 0 Then
				' 削除実行
				db.setSQL(sqlMTI_LEND.sqlDelLend_Ch)	'DELETE文設定
				db.setParam(sqlMTI_LEND.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_LEND.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setParam(sqlMTI_LEND.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
				db.setVal(sqlMTI_LEND.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_LEND.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_LEND.prmCH_NO, pChNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub
End Class
